#
# spec file for package nim
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           nim
Version:        1.2.12
Release:        lp152.2.3.1
Summary:        A statically typed, imperative programming language
License:        MIT
Group:          Development/Languages/Other
URL:            https://nim-lang.org/
Source0:        https://nim-lang.org/download/nim-%{version}.tar.xz
Source1:        nim-rpmlintrc
BuildRequires:  binutils-devel
# required for the testsuite
BuildRequires:  gc-devel
BuildRequires:  libopenssl-devel
BuildRequires:  sqlite3-devel
BuildRequires:  timezone
BuildRequires:  valgrind
%if 0%{?is_opensuse} || 0%{?is_backports}
# node is not available on armv7l armv7hl
%ifnarch armv7l armv7hl
# Leap 42.3 node is too old, but SLE backports is ok
%if 0%{?suse_version} >= 1500 || 0%{?is_backports}
BuildRequires:  nodejs
%endif
%endif
BuildRequires:  sfml2-devel
%endif
%if 0%{?suse_version} >= 1500
# -std=c++14 requires gcc 5.2, SLE and old Leap do not have it
BuildRequires:  gcc-c++ >= 5.2
%endif
#
Recommends:     git
ExclusiveArch:  %{ix86} x86_64 armv7l armv7hl aarch64 ppc64le

%description
Nim is a statically typed, imperative programming language.

Beneath a infix/indentation-based syntax with a (AST-based) macro
system lies a semantic model that supports a soft realtime GC on
thread local heaps. Asynchronous message passing is used between
threads. An unsafe shared memory heap is also provided for the
increased efficiency that results from that model.

%prep
%setup -q

%build
export CFLAGS="%{optflags}"
export NIMFLAGS="$(echo '%{optflags}' | sed 's/\([^[:space:]]\+\)/--passC:\1/g')"
export NIMFLAGS="$NIMFLAGS %{?jobs:--parallelBuild:%{jobs}}"

./build.sh

make %{?_smp_mflags} V=1 \
  CFLAGS="%{optflags}"
./bin/nim c $NIMFLAGS koch

./koch boot -d:release $NIMFLAGS \
  -d:useGnuReadline
./koch tools -d:release $NIMFLAGS

%check
#cat <<EOT >> skip
#tests/manyloc/keineschweine/keineschweine.nim
#tests/manyloc/keineschweine/server/sg_lobby.nim
#EOT

cat <<EOT >> skip
# FIXME list of tests that need to be reviewed and that are not passing
#
# Error: unhandled exception: No SSL/TLS CA certificates found. [IOError]
tests/stdlib/thttpclient_ssl.nim
#
# code reloading test fails
tests/dll/nimhcr_integration.nim
#
# [ 2047s] Failure: reTimeout
tests/vm/tslow_tables.nim
EOT

%ifarch aarch64 armv7l armv7hl ppc64le
cat <<EOT >> skip
# fails because it includes immintrin.h
tests/misc/tsizeof4.nim
# other
tests/dll/nimhcr_unit.nim
tests/range/tcompiletime_range_checks.nim
EOT
%endif

%if 0%{?sle_version} && 0%{?sle_version} < 150000
cat <<EOT >> skip
# compiler too old?
tests/misc/tsizeof4.nim
tests/destructor/tnewruntime_misc.nim
EOT
%endif

%if 0%{?sle_version} && !0%{?is_opensuse} && !0%{?is_backports}
cat <<EOT >> skip
# no SFML in plain SLE
tests/niminaction/Chapter8/sfml/sfml_test.nim
EOT
%endif

%ifarch i586
cat <<EOT >> skip
# crashes on i586
tests/destructor/tnewruntime_misc.nim
EOT
%endif

# Tests as many targets as possible
targets="c objc"
if rpm -q --whatprovides nodejs; then
    targets="$targets js"
fi
if rpm -q --whatprovides c++_compiler; then
    targets="$targets c++"
fi
./koch tests --nim:$PWD/bin/nim --failing --colors:off --skipFrom:skip --targets:"$targets" all

%install
./koch install %{buildroot}%{_libdir}

find . -name testament -executable -type f -delete

mkdir -p %{buildroot}%{_bindir}/ %{buildroot}%{_sysconfdir}/nim \
  %{buildroot}%{_docdir}/nim/

ls ./bin | while read f; do
    install -Dpm 0755 "./bin/$f" "%{buildroot}%{_libdir}/nim/bin/$f"
    ln -s "%{_libdir}/nim/bin/$f" "%{buildroot}%{_bindir}/$f"
done

mv -T %{buildroot}%{_libdir}/nim/config/ %{buildroot}%{_sysconfdir}/nim/

mv -T %{buildroot}%{_libdir}/nim/doc/ %{buildroot}%{_docdir}/nim/
ln -s %{_docdir}/nim/ %{buildroot}%{_libdir}/nim/doc

%files
%license copying.txt
%doc doc/advopt.txt doc/basicopt.txt
%doc %{_docdir}/nim/
%dir %{_sysconfdir}/nim
%config %{_sysconfdir}/nim/nim*.cfg
%{_bindir}/nim*
%{_libdir}/nim/

%changelog
* Wed Apr 21 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.2.12
  * Fixed GC crash resulting from inlining of the memory
    allocation procs
  * Fixed “incorrect raises effect for $(NimNode)” (#17454)
- from version 1.2.10
  * Fixed “JS backend doesn’t handle float->int type conversion “ (#8404)
  * Fixed “The “try except” not work when the “OSError:
    Too many open files” error occurs!” (#15925)
  * Fixed “Nim emits #line 0 C preprocessor directives with
    –debugger:native, with ICE in gcc-10” (#15942)
  * Fixed “tfuturevar fails when activated” (#9695)
  * Fixed “nre.escapeRe is not gcsafe” (#16103)
  * Fixed ““Error: internal error: genRecordFieldAux” - in
    the “version-1-4” branch” (#16069)
  * Fixed “-d:fulldebug switch does not compile with gc:arc” (#16214)
  * Fixed “osLastError may randomly raise defect and crash” (#16359)
  * Fixed “generic importc proc’s don’t work (breaking lots
    of vmops procs for js)” (#16428)
  * Fixed “Concept: codegen ignores parameter passing” (#16897)
  * Fixed “{.push exportc.} interacts with anonymous functions” (#16967)
  * Fixed “memory allocation during {.global.} init breaks GC” (#17085)
  * Fixed "Nimble arbitrary code execution for specially crafted package metadata"
    + https://github.com/nim-lang/security/security/advisories/GHSA-rg9f-w24h-962p
    + (bsc#1185083, CVE-2021-21372)
  * Fixed "Nimble falls back to insecure http url when fetching packages"
    + https://github.com/nim-lang/security/security/advisories/GHSA-8w52-r35x-rgp8
    + (bsc#1185084, CVE-2021-21373)
  * Fixed "Nimble fails to validate certificates due to insecure httpClient defaults"
    + https://github.com/nim-lang/security/security/advisories/GHSA-c2wm-v66h-xhxx
    + (bsc#1185085, CVE-2021-21374)
- from version 1.2.8
  * Fixed “Defer and –gc:arc” (#15071)
  * Fixed “Issue with –gc:arc at compile time” (#15129)
  * Fixed “Nil check on each field fails in generic function” (#15101)
  * Fixed “[strscans] scanf doesn’t match a single character with
    $+ if it’s the end of the string” (#15064)
  * Fixed “Crash and incorrect return values when using
    readPasswordFromStdin on Windows.” (#15207)
  * Fixed “Inconsistent unsigned -> signed RangeDefect usage
    across integer sizes” (#15210)
  * Fixed “toHex results in RangeDefect exception when
    used with large uint64” (#15257)
  * Fixed “Mixing ‘return’ with expressions is allowed in 1.2” (#15280)
  * Fixed “proc execCmdEx doesn’t work with -d:useWinAnsi” (#14203)
  * Fixed “memory corruption in tmarshall.nim” (#9754)
  * Fixed “Wrong number of variables” (#15360)
  * Fixed “defer doesnt work with block, break and await” (#15243)
  * Fixed “Sizeof of case object is incorrect. Showstopper” (#15516)
  * Fixed “Mixing ‘return’ with expressions is allowed in 1.2” (#15280)
  * Fixed “regression(1.0.2 => 1.0.4) VM register messed up
    depending on unrelated context” (#15704)
- from version 1.2.6
  * Fixed “The pegs module doesn’t work with generics!” (#14718)
  * Fixed “[goto exceptions] {.noReturn.} pragma is not detected
    in a case expression” (#14458)
  * Fixed “[exceptions:goto] C compiler error with dynlib pragma
    calling a proc” (#14240)
  * Fixed “Nim source archive install: ‘install.sh’ fails with error:
    cp: cannot stat ‘bin/nim-gdb’: No such file or directory” (#14748)
  * Fixed “Stropped identifiers don’t work as field names in
    tuple literals” (#14911)
  * Fixed “uri.decodeUrl crashes on incorrectly formatted input” (#14082)
  * Fixed “odbcsql module has some wrong integer types” (#9771)
  * Fixed “[ARC] Compiler crash declaring a finalizer proc
    directly in ‘new’” (#15044)
  * Fixed “code with named arguments in proc of winim/com can
    not been compiled” (#15056)
  * Fixed “javascript backend produces javascript code with syntax
    error in object syntax” (#14534)
  * Fixed “[ARC] SIGSEGV when calling a closure as a tuple
    field in a seq” (#15038)
  * Fixed “Compiler crashes when using string as object variant
    selector with else branch” (#14189)
  * Fixed “Constructing a uint64 range on a 32-bit machine leads
    to incorrect codegen” (#14616)
* Sun Jun 21 2020 dmacvicar@suse.com
- Update to version 1.2.2:
  * See https://nim-lang.org/blog.html for details
- Enable the full testsuite in the %%check section
  * Add build dependencies to run the testsuite
  * Whitelists a few tests that are not passing yet
* Wed Nov 13 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 1.0.2:
  * See https://nim-lang.org/blog.html for details
- Update dependencies (based on changes by Federico Ceratto
* Mon Jun  3 2019 m.szczepaniak.000@gmail.com
- Added ppc64le
* Mon Jun  3 2019 m.szczepaniak.000@gmail.com
- Added armv7l and aarch64
* Fri May 31 2019 Martin Pluskal <mpluskal@suse.com>
- Force more optflags usage
- Fix location of config files (boo#1137006)
* Tue May 14 2019 m.szczepaniak.000@gmail.com
- Update to version 0.19.6:
  Please see:
  https://nim-lang.org/blog/2019/05/13/version-0196-released.html
* Tue Jan  1 2019 mvetter@suse.com
- Update to version 0.19.2:
  Please see:
  https://nim-lang.org/blog/2018/12/31/version-0192-released.html
* Mon Oct 22 2018 mvetter@suse.com
- Update to version 0.19.0:
  * Please see:
    https://nim-lang.org/blog/2018/09/26/version-0190-released.html
* Fri Mar  2 2018 mvetter@suse.com
- Update to version 0.18.0:
  * Please see:
    https://nim-lang.org/blog/2018/03/01/version-0180-released.html
- Add nim-rpmlintrc
* Fri Jan  5 2018 mpluskal@suse.com
- Update to version 0.17.2:
  * Bugfix release
  * For details see:
    https://nim-lang.org/blog/2017/09/07/version-0172-released.html
* Sat Jun  3 2017 mpluskal@suse.com
- Update to version 0.17.0:
  * https://nim-lang.org/blog/2017/05/17/version-0170-released.html
* Sat Mar 11 2017 mpluskal@suse.com
- Update list of files to fix building on Factory
* Thu Mar  2 2017 jengelh@inai.de
- Update description
* Sun Feb 19 2017 sor.alexei@meowr.ru
- Update to version 0.16.0:
  * No changelog available.
- Build and install libraries, etc.
- Install configuration files.
- Recommend git for nimble.
* Fri Dec 23 2016 mpluskal@suse.com
- Cleanup package to follow packaging guidelines
* Fri Dec 23 2016 thomazi@linux.com
- Fixing spec summary
